Enum pddl_parser::domain::action::Action
source · pub enum Action {
Simple(SimpleAction),
Durative(DurativeAction),
}Expand description
Enum to represent either an Action or a DurativeAction.
Variants
Simple(SimpleAction)
An Action wrapper around a simple action. See SimpleAction.
Durative(DurativeAction)
An Action wrapper around a durative action. See DurativeAction.
Implementations
sourceimpl Action
impl Action
sourcepub fn name(&self) -> &str
pub fn name(&self) -> &str
Get the name of the action. This is the same as the name of the simple or durative action.
sourcepub fn parameters(&self) -> &[TypedParameter]
pub fn parameters(&self) -> &[TypedParameter]
Get the parameters of the action. This is the same as the parameters of the simple or durative action.
sourcepub fn precondition(&self) -> Option<Expression>
pub fn precondition(&self) -> Option<Expression>
Get the precondition of the action. This is the same as the precondition of the simple or durative action.
sourcepub fn effect(&self) -> Expression
pub fn effect(&self) -> Expression
Get the effect of the action. This is the same as the effect of the simple or durative action.
sourcepub fn parse(
input: TokenStream<'_>
) -> IResult<TokenStream<'_>, Action, ParserError>
pub fn parse( input: TokenStream<'_> ) -> IResult<TokenStream<'_>, Action, ParserError>
Parse an action from a token stream.