Enum pddl_parser::domain::expression::DurationInstant
source · pub enum DurationInstant {
Start,
End,
All,
}Expand description
An enumeration of duration instants that can be used in expressions. The duration instant can be one of at start, at end, or over all.
Variants
Start
The duration instant at start represents the start of the action.
End
The duration instant at end represents the end of the action.
All
The duration instant over all represents the entire duration of the action.