Module typed_predicate

Module typed_predicate 

This module contains the definition of a typed predicate. A typed predicate is a function that takes a set of parameters and returns a boolean. The type of the parameters is specified explicitly.

Structs

TypedPredicate
A predicate with typed parameters.