Struct pddl_parser::domain::typed_predicate::TypedPredicate
source · pub struct TypedPredicate {
pub name: String,
pub parameters: Vec<TypedParameter>,
}Expand description
A predicate with typed parameters.
Fields
name: StringThe name of the predicate.
parameters: Vec<TypedParameter>The parameters of the predicate.
Implementations
sourceimpl TypedPredicate
impl TypedPredicate
sourcepub fn parse_functions(
input: TokenStream<'_>
) -> IResult<TokenStream<'_>, Vec<TypedPredicate>, ParserError>
pub fn parse_functions( input: TokenStream<'_> ) -> IResult<TokenStream<'_>, Vec<TypedPredicate>, ParserError>
Parse a list of functions from a token stream.
sourcepub fn parse_predicates(
input: TokenStream<'_>
) -> IResult<TokenStream<'_>, Vec<TypedPredicate>, ParserError>
pub fn parse_predicates( input: TokenStream<'_> ) -> IResult<TokenStream<'_>, Vec<TypedPredicate>, ParserError>
Parse a list of predicates from a token stream.