Enum pddl_parser::domain::typing::Type
source · pub enum Type {
Simple(String),
Either(Vec<String>),
}Expand description
A type is either a simple type or one of the list of specified types.
Variants
Simple(String)
The type is a simple type.
Either(Vec<String>)
The type must be one of the specified types.
Implementations
sourceimpl Type
impl Type
sourcepub fn parse_type(
input: TokenStream<'_>
) -> IResult<TokenStream<'_>, Type, ParserError>
pub fn parse_type( input: TokenStream<'_> ) -> IResult<TokenStream<'_>, Type, ParserError>
Parse a type from a token stream.
sourcepub fn parse_types(
input: TokenStream<'_>
) -> IResult<TokenStream<'_>, Vec<TypeDef>, ParserError>
pub fn parse_types( input: TokenStream<'_> ) -> IResult<TokenStream<'_>, Vec<TypeDef>, ParserError>
Parse a list of types from a token stream.