Struct pddl_parser::lexer::TokenStream
source · pub struct TokenStream<'a> { /* private fields */ }Expand description
A stream of tokens. This is a wrapper around a logos::Lexer. It implements Clone, so it can be cloned and used to peek ahead. It also implements Iterator, so it can be used to iterate over the tokens.
Implementations
sourceimpl<'a> TokenStream<'a>
impl<'a> TokenStream<'a>
sourcepub fn new(input: &'a str) -> Self
pub fn new(input: &'a str) -> Self
Creates a new token stream from the given input string. The input string is not copied, so it must outlive the token stream.
sourcepub fn peek(&self) -> Option<(Result<Token, ParserError>, &'a str)>
pub fn peek(&self) -> Option<(Result<Token, ParserError>, &'a str)>
Returns the next token in the stream, or None if the stream is empty.