pub struct DurativeAction {
pub name: String,
pub parameters: Vec<Parameter>,
pub duration: f64,
pub timestamp: f64,
}Expand description
A durative action is an action that has a duration.
Fields
name: StringThe name of the action.
parameters: Vec<Parameter>The parameters of the action.
duration: f64The duration of the action.
timestamp: f64The condition of the action.
Implementations
Sourceimpl DurativeAction
impl DurativeAction
Sourcepub const fn new(
name: String,
parameters: Vec<Parameter>,
duration: f64,
timestamp: f64,
) -> Self
pub const fn new( name: String, parameters: Vec<Parameter>, duration: f64, timestamp: f64, ) -> Self
Create a new durative action. This is the same as the simple action, but with a duration and a timestamp.
Arguments
name- The name of the action.parameters- The parameters of the action.duration- The duration of the action. This is the time it takes for the action to complete.timestamp- The timestamp of the action. This is the time at which the action starts.
Sourcepub fn parse(
input: TokenStream<'_>,
) -> IResult<TokenStream<'_>, Self, ParserError>
pub fn parse( input: TokenStream<'_>, ) -> IResult<TokenStream<'_>, Self, ParserError>
Parse a durative action from a token stream.