Struct pddl_parser::plan::Plan

source ·
pub struct Plan(pub Vec<Action>);
A plan is a sequence of actions.

The order of the actions is important. Plan is a wrapper around a Vec<Action> that implements IntoIterator and FromIterator<Action>. This might change in the future.

Tuple Fields

0: Vec<Action>

Implementations

source

impl Plan

source

pub fn parse(input: TokenStream<'_>) -> Result<Self, ParserError>

Parse a plan from a token stream.

The plan must be a sequence of actions. The parser will fail if there are any tokens left after the plan.

Errors

The parser will fail if there are any tokens left after the plan. It will also fail if the plan is empty or if any of the actions are invalid.

source

pub fn actions(&self) -> impl Iterator<Item = &Action>

Get an iterator over the actions in the plan.