pub struct Problem {
    pub name: String,
    pub domain: String,
    pub objects: Vec<Object>,
    pub init: Vec<Predicate>,
    pub goal: Expression,
}
A PDDL problem

A problem is a description of a particular planning problem. It consists of a domain, a set of objects, an initial state, and a goal state.

Fields

name: String

The name of the problem

domain: String

The name of the domain of the problem

objects: Vec<Object>

The objects of the problem

init: Vec<Predicate>

The initial state of the problem

goal: Expression

The goal of the problem

Implementations

source

impl Problem

source

pub fn parse(input: TokenStream<'_>) -> Result<Self, ParserError>

Parse a PDDL problem

source

pub fn to_pddl(&self) -> String

Convert the problem to PDDL format (as a string) for writing to a file