This module contains the definition of an expression. An expression is a function that takes a set of parameters and returns a value.
Enums
- Binary
Op - An enumeration of binary operations that can be used in expressions.
- Duration
Instant - An enumeration of duration instants that can be used in expressions. The duration instant can be one of
at start,at end, orover all. - Expression
- An enumeration of expressions that can be used in PDDL planning domains and problems.