Struct pddl_parser::problem::Problem
source · pub struct Problem {
pub name: String,
pub domain: String,
pub objects: Vec<Object>,
pub init: Vec<Predicate>,
pub goal: Expression,
}Expand description
A PDDL problem
A problem is a description of a particular planning problem. It consists of a domain, a set of objects, an initial state, and a goal state.
Fields
name: StringThe name of the problem
domain: StringThe name of the domain of the problem
objects: Vec<Object>The objects of the problem
init: Vec<Predicate>The initial state of the problem
goal: ExpressionThe goal of the problem
Implementations